import "file";

/*
 * This main function makes a roadmap given a roads.txt file.
 * It then checks whether pairs of cities are reached in two steps
 * to test the implementation of isReachableInTwo.
 */
function main() {
	const filename = "roads.txt";
	var roadmap = {};
	populateRoadmap(roadmap, filename);
	if (isReachableInTwo("Los Angeles", "San Diego", roadmap)) console.log("pass");
	if (isReachableInTwo("San Francisco", "Reno", roadmap)) console.log("pass");
	if (!isReachableInTwo("San Francisco", "Salt Lake City", roadmap)) console.log("pass");
}

/*
 * This function takes a roadmap object and a filename as inputs.
 * It parses the file and populates the roadmap so that it 
 * represents what cities each city is connected to. 
 */
function populateRoadmap(roadmap, filename) {
	var lines = File.readLines(filename);
	var delimiter = " - ";
	for (var i = 0; i < lines.length; i++) {
		var line = lines[i];
		var cutoff = line.indexOf(delimiter); 
		var cityOne = line.substring(0, cutoff);
		var cityTwo = line.substring(cutoff + delimiter.length);
		if (roadmap[cityOne] === undefined) {
			roadmap[cityOne] = [];
		}
		if (roadmap[cityTwo] === undefined) {
			roadmap[cityTwo] = [];
		}
		roadmap[cityOne].push(cityTwo);
		roadmap[cityTwo].push(cityOne);
	}
	//do we need to return roadmap here? why or why not?
	//answer: no, roadmap is an object, thus passed by reference.
}

/*
 * This function takes two cities and a roadmap and returns
 * a boolean of whether the two cities can be reached within
 * two roads. 
 */
function isReachableInTwo(currentCity, destinationCity, roadmap) {
	if (currentCity === destinationCity) return true;
	var firstLevelNeighbors = roadmap[currentCity];
	for (var i = 0; i < firstLevelNeighbors.length; i++) {
		var firstNeighbor = firstLevelNeighbors[i];
		if (firstNeighbor === destinationCity) return true;
		var secondLevelNeighbors = roadmap[firstNeighbor];
		for (var j = 0; j < secondLevelNeighbors.length; j++) {
			var secondNeighbor = secondLevelNeighbors[j];
			if (secondNeighbor === destinationCity) {
				return true;
			}
		}
	}
	return false;
}
