import "file";

/*
 * Makes a potion collection from the potionsFile.
 * Then, allows the user to enter the name of a potion.
 * The program outputs the ingredients for that potion.
 */
function main() {
	const potionsFile = "potions.txt";
	var potionCollection = PotionCollection(potionsFile);
	var callback = function(name) {
		var potion = potionCollection.getPotion(name);
		if (potion !== null) {
			var ingredients = potion.getIngredients();
			for (var i = 0; i < ingredients.length; i++) {
				console.log(ingredients[i]);
			}
		}
		console.requestInput("Enter name of the potion: ", callback);
	};
	console.requestInput("Enter name of the potion: ", callback);
}

/*
 * The Potion class takes the name of the potion and 
 * returns an object that contains the functions to get
 * the names and ingredients of the potion, as well as
 * to add an ingredient. 
 */
function Potion(name) {
	var ingredientList = [];
	return {
		getName: function() {
			return name;
		},
		getIngredients: function() {
			return ingredientList;
		},
		addIngredient: function(ingredient) {
			ingredientList.push(ingredient);
		}
	};
}

/*
 * The PotionCollection class takes a filename of potions.
 * It adds all the potions in the file into a PotionCollection
 * and returns an object that contains the functions to get
 * a potion or get all potion names. 
 */
function PotionCollection(filename) {
	//open file
	var lines = File.readLines(filename);
	if (lines === undefined) return null;
	var collection = {};

	//add potions from file
	var line_num = 0;
	while (line_num < lines.length) {
		var name = lines[line_num];
		line_num++;
		var potion = Potion(name);
		while (true) {
			var line = lines[line_num];
			line_num++;
			if (line_num >= lines.length || line === "") break;
			potion.addIngredient(line);
		}
		collection[name] = potion;
	}

	return {
		getPotion: function(name) {
			if (collection[name] === undefined) return null;
			else return collection[name];
		},
		getPotionNames: function(name) {
			var keys = [];
			for (var key in collection) {
				keys.push(key);
			}
			return keys;
			//ignore the order in which they appeared in file. 
		}
	};
}



